@@ -1,4 +1,5 @@
 """Common methods for parsing."""
+
 import enum
 import typing as T
 
@@ -137,10 +138,12 @@ class DocstringExample(DocstringMeta):
     def __init__(
         self,
         args: T.List[str],
+        snippet: T.Optional[str],
         description: T.Optional[str],
     ) -> None:
         """Initialize self."""
         super().__init__(args, description)
+        self.snippet = snippet
         self.description = description
 
 
@@ -159,6 +162,25 @@ class Docstring:
         self.meta = []  # type: T.List[DocstringMeta]
         self.style = style  # type: T.Optional[DocstringStyle]
 
+    @property
+    def description(self) -> T.Optional[str]:
+        """Return the full description of the function
+
+        Returns None if the docstring did not include any description
+        """
+        ret = []
+        if self.short_description:
+            ret.append(self.short_description)
+            if self.blank_after_short_description:
+                ret.append("")
+        if self.long_description:
+            ret.append(self.long_description)
+
+        if not ret:
+            return None
+
+        return "\n".join(ret)
+
     @property
     def params(self) -> T.List[DocstringParam]:
         """Return a list of information on function params."""
